<?php
/*
Plugin Name: Advanced Layout Extension for WordPress (ALEW)
Description: WordPress framework extension for an easier control of design's layout. See manual at <a href="options-general.php?page=alew/help.php">Options | ALEW</a>.
Version: 1.1

*/
/*  Copyright 2006  Eric Desgranges

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
/*  Layout functions are listed in the admin section: Options | ALEW
*/

load_plugin_textdomain('alew', 'wp-content/plugins/alew');

add_action('admin_menu', array('alew', 'plugin_admin'));


# ----------------------------------
function alew_teaser($min_height = NULL, $max_height = NULL, $more_link_text = NULL, $strip_tags = NULL, $img_format = NULL) {
# ----------------------------------
# Recommended placement of the more tag. Example:
# This is the end of your paragraph.
# (new line)
# <!--more-->This is the beginning of your new paragraph 
# ----------------------------------
    
  // Taken from the get_the_content function in template-functions-post.php
  
	global $id, $post, $more, $single, $withcomments, $page, $pages, $multipage, $numpages;
	global $preview;
	global $pagenow;
	$output = '';

    # Check if there's a password (and it doesn't match the cookie)
	if ( !empty($post->post_password) ) {
	  if ( stripslashes($_COOKIE['wp-postpass_'.COOKIEHASH]) != $post->post_password ) {	
		$output = get_the_password_form();
		echo $output;
		return;
	  };
	};

    # Separate teaser from content
	$content = $pages[$page-1];
	$content = explode('<!--more-->', $content, 2);
	$teaser = $content[0];
	if (($content[0] == $pages[$page-1]) && (!isset($img_format))) {
	  # more tag not present, there's no need to put link
	  $more_link_text = '<!--no-link-->';
	};
	
	# preview fix for javascript bug with foreign languages 
	if ( $preview ) { 
		$teaser = preg_replace('/\%u([0-9A-F]{4,4})/e', "'&#'.base_convert('\\1',16,10).';'", $teaser);
    };   
	
    $teaser = apply_filters('the_content', $teaser);
    $teaser = str_replace(']]>', ']]&gt;', $teaser);
	
	if (isset($img_format)) {
	  # <img id="image20" src="http://domain.com/wp-content/uploads/2006/05/drawing.jpg" alt="Testing..." />
	  # --> <img id="image20" src="http://domain.com/wp-content/uploads/2006/05/drawing.miniature.jpg" alt="Testing..." />
	  $pattern = '@<img\s*id\s*=\s*\"(.*?)\"\s*src\s*=\s*\"(.*\/)(.*?)\.(jpg|bmp)\"\s*(.*?)>@i';
	  $string = "<img id=\"$1\" src=\"$2$3.$img_format.$4\" $5>";
	  $teaser = preg_replace($pattern, $string, $teaser);
    };
		
	# if $strip_tags is set we strip out all the tags, except those in $strip_tags
	# Example: $strip_tags = '<a><br><b><h1><h2><h3><h4><i><img><li><ol><p><strong><table><tr><td><th><u><ul>'
	# We also remove the links before wrapping everyting within a main link, if $more_link_text is not set
	if (!isset($more_link_text) || (isset($more_link_text) && ($more_link_text == '<!--no-link-->'))) {
	  #if (!isset($more_link_text) && (isset($strip_tags))) { str_replace('<a>', '', $strip_tags); };
	  if (isset($strip_tags)) { $teaser = strip_tags($teaser, $strip_tags); };
	  # We now wrap everything within <a>..</a>
      if (!isset($more_link_text)) { $teaser = ' <a style="display: block;" href="'. get_permalink() . '" class="more">'.$teaser."</a>"; };  
	} else if (!isset($strip_tags)) {
	  $teaser = $teaser.' <a href="'. get_permalink() . '" class="more">'.$more_link_text."</a>";
	} else {
	  $teaser = strip_tags($teaser, $strip_tags);
	  $teaser = $teaser.' <a href="'. get_permalink() . '" class="more">'.$more_link_text."</a>";
	};
	
    if (isset($min_height) || isset($max_height)) {
	  $style = "display: block; overflow: auto;";
	  if ($min_height == $max_height) {
	    # Replace with css tag height, at least IE6- understands it!
	    $style .= " height: $min_height;";
	  } else {   
	    $style .= ((isset($min_height))? " min-height: $min_height;" : "") 
		        . ((isset($max_height))? " max-height: $max_height;" : "");
	  };		  
      $teaser = '<div style="'.$style.'">'."\r\n\r\n".$teaser.'</div>';
    };	
    
	
    echo $teaser;
  
}


# ----------------------------------
function alew_excerpt($min_height = NULL, $max_height = NULL, $more_link_text = NULL, $strip_tags = NULL) {
# ----------------------------------
# Recommended placement of the more tag. Example:
# This is the end of your paragraph.
# (new line)
# <!--more-->This is the beginning of your new paragraph 
# ----------------------------------
    
  // Taken from the get_the_excerpt function in template-functions-post.php
  
	global $id, $post;
	
	$output = '';
	$output = $post->post_excerpt;
	if ( !empty($post->post_password) ) { 
	    // there's a password
		if ( $_COOKIE['wp-postpass_'.COOKIEHASH] != $post->post_password ) {  
		    // and it doesn't match the cookie
			$output = __('There is no excerpt because this is a protected post.');
			return $output;
		}
	}
	
	if (!$output) {
      
	  # Display the teaser if no excerpt was written
	  alew_teaser($min_height, $max_height, $more_link_text, $strip_tags);

	} else {

      $output = apply_filters('the_excerpt', $output);
	  
	  # if $strip_tags is set we strip out all the tags, except those in $strip_tags
	  # Example: $strip_tags = '<a><br><b><h1><h2><h3><h4><i><img><li><ol><p><strong><table><tr><td><th><u><ul>'
	  # We also remove the links before wrapping everyting within a main link, if $more_link_text is not set
	  if (!isset($more_link_text) || (isset($more_link_text) && ($more_link_text == '<!--no-link-->'))) {
	    #if (!isset($more_link_text) && (isset($strip_tags))) { str_replace('<a>', '', $strip_tags); };
	    if (isset($strip_tags)) { $output = strip_tags($output, $strip_tags); };
	    # We now wrap everything within <a>..</a>
        if (!isset($more_link_text)) { $output = ' <a style="display: block;" href="'. get_permalink() . '" class="more">'.$output."</a>"; };  
	  } else if (!isset($strip_tags)) {
	    $output = $output.' <a href="'. get_permalink() . '" class="more">'.$more_link_text."</a>";
	  } else {
	    $output = strip_tags($output, $strip_tags);
	    $output = $output.' <a href="'. get_permalink() . '" class="more">'.$more_link_text."</a>";
	  };
	

      if (isset($min_height) || isset($max_height)) {
	    $style = "display: block; overflow: auto;";
	    if ($min_height == $max_height) {
	      # Replace with css tag height, at least IE6- understands it!
	      $style .= " height: $min_height;";
	    } else {   
	      $style .= ((isset($min_height))? " min-height: $min_height;" : "") 
		         . ((isset($max_height))? " max-height: $max_height;" : "");
	    };		  
        $output = '<div style="'.$style.'">'."\r\n\r\n".$output.'</div>';
	  };	

      echo $output;
	  
	};  
  
}


# ----------------------------------
function alew_recent_posts($post_count, $offset_count = 0) {
# ----------------------------------
// Template tag: alew_recent_posts()
// List the $post_count most recent posts exluding the last post.
# ----------------------------------
  global $post;

	$posts = get_posts('numberposts='.$post_count.'&offset='.$offset_count);
	if ($posts) { ?>
				
		<li class="posts">
		<h3><?php _e('Recent posts', 'alew'); ?></h3>
		<ul>
					
			<?php foreach($posts as $post) : ?>
			<li><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></li>
			<?php endforeach; ?>
		</ul>
		</li>
					
	<?php } ?>
<?php
}


# ----------------------------------
function alew_sticky_page($sticky_page, $page = NULL) {
# ----------------------------------
// This function displays the content of the page $sticky_page
// The optional second argument is a page name to which $sticky_page can link via 'Read more'.
# ----------------------------------
	
	if ($page <> NULL) {
		$query = new WP_Query('pagename='.$page);

		while ($query->have_posts()) : $query->the_post();
			$more_url = '<a href="'. get_permalink() .'" title="Permalink" class="more-link">'.__('Read more', 'alew').'</a>';
		endwhile;
	};	
	
	if ($sticky_page <> NULL) {			
		$query = new WP_Query('pagename='.$sticky_page);
								
		while ($query->have_posts()) : $query->the_post();
		?>
			<h3><?php the_title(); ?></h3>
			<?php the_content(); 
			if ($more_url != "") { 
				?> <p class="entry-meta"><?php echo $more_url; ?></p><?php
			}?>
						
		<?php endwhile;
	};	
	
}


# ----------------------------------
function alew_class($in_tag) {
# ----------------------------------
// Returns class name depending on context
// Requires in_tag in ('body' | 'post' | 'comment')
# ----------------------------------
	global $alew_post_count, $alew_comment_count, $alew_trackback_count;
	
	if (strtolower($in_tag) === 'body') {
		if      (is_home()) 				{ return 'home'; }
		else if (is_single())				{ return 'single'; }
		else if (is_page()) 				{ return 'page'; }
		else if (is_category())			{ return 'category'; }
		else if (is_archive()) 			{ return 'archive'; }
		else if (is_date())  				{ return 'date'; }
		else if (is_paged()) 				{ return 'paged'; }
		else if (is_attachment()) 	{ return 'attachment'; }
		else if (is_author())				{ return 'author'; }
		else if (is_search())  			{ return 'search'; }
		else if (is_404()) 					{ return 'error404'; }
		
	} else if (strtolower($in_tag) === 'post') {
		if (!isset($alew_post_count)) { $alew_post_count = 1;	} else { $alew_post_count = $alew_post_count + 1;	};
		if ($alew_post_count % 2 <> 0) { return 'hentry'; } else { return 'hentry alt'; };
		
	} else if (strtolower($in_tag) === 'comment') {
	  if (get_comment_type() === 'comment') {
		  // It's a comment
			if (!isset($alew_comment_count)) { $alew_comment_count = 1;	} else { $alew_comment_count = $alew_comment_count + 1;	};
			if ($alew_comment_count % 2 <> 0) { return 'comment'; } else { return 'comment alt'; };
	  } else { 
		  // It's a trackback or ping
			if (!isset($alew_trackback_count)) { $alew_trackback_count = 1;	} else { $alew_trackback_count = $alew_trackback_count + 1;	};
			if ($alew_trackback_count % 2 <> 0) { return 'trackback'; } else { return 'trackback alt'; };
		};
	};
	
}



####################################
class alew {
####################################


# ----------------------------------
function plugin_admin() {
# ----------------------------------
if( function_exists('add_options_page')) {
  add_options_page('ALEW', 'ALEW', 7, 'alew/help.php');
};  
return;
}



####################################
}
####################################
?>